# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chatservice.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'chatservice.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63hatservice.proto\"u\n\x12\x43hatMessageRequest\x12\x11\n\tthread_id\x18\x01 \x01(\x04\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x11\n\tsender_id\x18\x03 \x01(\t\x12\x14\n\x0crecipient_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\"!\n\x13\x43hatMessageResponse\x12\n\n\x02id\x18\x01 \x01(\x04\"\x8d\x01\n\x0b\x43hatMessage\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x11\n\tthread_id\x18\x02 \x01(\x04\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x11\n\tsender_id\x18\x04 \x01(\t\x12\x14\n\x0crecipient_id\x18\x05 \x01(\t\x12\x12\n\nsession_id\x18\x06 \x01(\t\x12\x11\n\ttimestamp\x18\x07 \x01(\t\"6\n\nChatClient\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t2w\n\x0b\x43hatService\x12\x38\n\x0bSendMessage\x12\x13.ChatMessageRequest\x1a\x14.ChatMessageResponse\x12.\n\x0fReceiveMessages\x12\x0b.ChatClient\x1a\x0c.ChatMessage0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chatservice_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHATMESSAGEREQUEST']._serialized_start=21
  _globals['_CHATMESSAGEREQUEST']._serialized_end=138
  _globals['_CHATMESSAGERESPONSE']._serialized_start=140
  _globals['_CHATMESSAGERESPONSE']._serialized_end=173
  _globals['_CHATMESSAGE']._serialized_start=176
  _globals['_CHATMESSAGE']._serialized_end=317
  _globals['_CHATCLIENT']._serialized_start=319
  _globals['_CHATCLIENT']._serialized_end=373
  _globals['_CHATSERVICE']._serialized_start=375
  _globals['_CHATSERVICE']._serialized_end=494
# @@protoc_insertion_point(module_scope)
